@@ -1,4 +1,4 @@
-/* $Id: filter.c,v 1.7 2004/09/16 13:26:14 pekberg Exp $
+/* $Id: filter.c,v 1.11 2005/08/04 16:36:37 soyt Exp $
 ******************************************************************************
 
    Filter-save - save away an eventstream for later playback
@@ -27,9 +27,9 @@
 */
 
 #include "config.h"
+#include <ggi/internal/gg_replace.h>
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
-#include <ggi/internal/gii_target.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -48,8 +48,8 @@ static int
 GII_save_handler(gii_input *inp, gii_event *event)
 {
 	save_priv *priv = inp->priv;
-	GIIDPRINT_LIBS("filter-save handler,priv=%p file=%p\n",
-			priv,priv->output);
+	DPRINT_LIBS("filter-save handler,priv=%p file=%p\n",
+		    priv,priv->output);
 	
 	fwrite(event, event->any.size, 1, priv->output);
 	
@@ -62,7 +62,7 @@ GII_save_close(gii_input *inp)
 {
 	save_priv *priv = inp->priv;
 
-	GIIDPRINT_LIBS("GII_save_close(%p) called\n", inp);
+	DPRINT_LIBS("GII_save_close(%p) called\n", inp);
 
 	fflush(priv->output);
 	
@@ -78,18 +78,20 @@ GII_save_close(gii_input *inp)
 	}
 	free(priv);
 
-	GIIDPRINT_LIBS("GII_save_close done\n");
+	DPRINT_LIBS("GII_save_close done\n");
 
 	return 0;
 }
 
 
-int GIIdlinit(gii_input *inp, const char *args, void *argptr)
+EXPORTFUNC int GIIdl_filter_save(gii_input *inp, const char *args, void *argptr);
+
+int GIIdl_filter_save(gii_input *inp, const char *args, void *argptr)
 {
 	save_priv   *priv;
 
-	GIIDPRINT_LIBS("filter-save init(%p, \"%s\") called\n", inp,
-		       args ? args : "");
+	DPRINT_LIBS("filter-save init(%p, \"%s\") called\n", inp,
+		    args ? args : "");
 
 	priv = malloc(sizeof(save_priv));
 	if (priv == NULL) return GGI_ENOMEM;
@@ -118,9 +120,9 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->priv       = priv;
 	inp->GIIhandler = GII_save_handler;
 	inp->GIIclose   = GII_save_close;
-
-	GIIDPRINT_LIBS("filter-save fully up, priv=%p file=%p\n",
-			priv,priv->output);
-
+	
+	DPRINT_LIBS("filter-save fully up, priv=%p file=%p\n",
+		    priv,priv->output);
+	
 	return 0;
 }
