@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: cpuid.c,v 1.14 2005/01/11 09:40:24 pekberg Exp $
 ***************************************************************************
 
    LibGG - General runtime CPU-type detection code.
@@ -34,22 +34,27 @@
 #ifdef HAVE_NO_SWARTYPE_IMPLEMENTATION
 /* State of CPU detection/selection is kept here. */
 static int cpuid_tested = 0;
-enum gg_swartype swars_detected = 0;
-enum gg_swartype swars_enabled = GG_SWAR_ALL;
+gg_swartype swars_detected = 0;
+gg_swartype swars_enabled = GG_SWAR_ALL;
 
 
-enum gg_swartype ggGetSwarType(void)
+gg_swartype ggGetSwarType(void)
 {
 	/* By default we assume the C SWARs all are faster if the arch
 	 * has the types. This may not be true everywhere, but those archs 
 	 * can define their own implementation.
 	 */
-	return GG_SWAR_NONE | GG_SWAR_32BITC	/* This needs ifdeffing too */
-#if 0				/* Better assume to have 32bit machines by default. */
-# ifdef GG_HAVE_INT64
-	    | GG_SWAR_64BITC
-# endif
-#endif
-	    ;
+
+	/* 64bit CPUs can run in 32bit (emulation) mode and 64bit mode.
+	 * When 64bit CPUs actually run in 64bit mode,
+	 * sizeof(void *) == 8  
+         */
+	if (sizeof(void *) == 8) {
+		/* Yeah, we are in 64bit mode */
+		swars_detected |= GG_SWAR_64BITC;
+	}
+
+	return (swars_enabled &
+		(swars_detected | GG_SWAR_NONE | GG_SWAR_32BITC));
 }
 #endif
