@@ -1,4 +1,4 @@
-/* $Id: packetparse.c,v 1.4 2003/07/04 22:38:29 cegger Exp $
+/* $Id$
 ******************************************************************************
 
    Mouse packet parsing
@@ -36,8 +36,8 @@
  **  Event dispatching routines
  **/
 
-static void mouse_send_movement(gii_input *inp, sint32 dx, sint32 dy,
-				sint32 dz, sint32 wheel)
+static void mouse_send_movement(gii_input *inp, int32_t dx, int32_t dy,
+				int32_t dz, int32_t wheel)
 {
 	gii_event ev;
 
@@ -60,11 +60,11 @@ static void mouse_send_movement(gii_input *inp, sint32 dx, sint32 dy,
 	}
 }
 
-static void mouse_send_buttons(gii_input *inp, uint32 buttons, uint32 last)
+static void mouse_send_buttons(gii_input *inp, uint32_t buttons, uint32_t last)
 {
 	gii_event ev;
-	uint32 mask;
-	uint32 changed = buttons ^ last;
+	uint32_t mask;
+	uint32_t changed = buttons ^ last;
 	int nr;
 
 	for (nr = 1, mask = 1; mask != 0; nr++, mask <<= 1) {
@@ -103,7 +103,7 @@ static void mouse_send_buttons(gii_input *inp, uint32 buttons, uint32 last)
 ******************************************************************************
 */
 
-static int parse_null(gii_input *inp, uint8 *buf, int len)
+static int parse_null(gii_input *inp, uint8_t *buf, int len)
 {
 	return len;
 }
@@ -114,7 +114,7 @@ static int parse_null(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_ms(gii_input *inp, uint8 *buf, int len)
+static int parse_ms(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy;
 	unsigned int buttons;
@@ -122,12 +122,12 @@ static int parse_ms(gii_input *inp, uint8 *buf, int len)
 
 	/* check header */
 	if (((buf[0] & 0x40) != 0x40) || ((buf[1] & 0x40) != 0x00)) {
-		GIIDPRINT_EVENTS("Invalid microsoft packet\n");
+		DPRINT_EVENTS("Invalid microsoft packet\n");
 		return 1;
 	}
 
-	dx = (sint8) (((buf[0] & 0x03) << 6) | (buf[1] & 0x3f));
-	dy = (sint8) (((buf[0] & 0x0c) << 4) | (buf[2] & 0x3f));
+	dx = (int8_t) (((buf[0] & 0x03) << 6) | (buf[1] & 0x3f));
+	dy = (int8_t) (((buf[0] & 0x0c) << 4) | (buf[2] & 0x3f));
 
 	/* Third button added by Christoph Egger
 	   (Christoph_Egger@t-online.de) */
@@ -154,7 +154,7 @@ static int parse_ms(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got microsoft packet\n");
+	DPRINT_EVENTS("Got microsoft packet\n");
 
 	return 3;
 } 
@@ -166,7 +166,7 @@ static int parse_ms(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_ms3(gii_input *inp, uint8 *buf, int len)
+static int parse_ms3(gii_input *inp, uint8_t *buf, int len)
 {
 	int wheel;
 	unsigned int buttons;
@@ -176,12 +176,12 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 		int dx, dy;
 		/* check header */
 		if (((buf[0] & 0x40) != 0x40) || ((buf[1] & 0x40) != 0x00)) {
-			GIIDPRINT_EVENTS("Invalid IntelliMouse packet\n");
+			DPRINT_EVENTS("Invalid IntelliMouse packet\n");
 			return 1;
 		}
 		
-		dx = (sint8) (((buf[0] & 0x03) << 6) | (buf[1] & 0x3f));
-		dy = (sint8) (((buf[0] & 0x0c) << 4) | (buf[2] & 0x3f));
+		dx = (int8_t) (((buf[0] & 0x03) << 6) | (buf[1] & 0x3f));
+		dy = (int8_t) (((buf[0] & 0x0c) << 4) | (buf[2] & 0x3f));
 		
 		buttons = ((buf[0] & 0x10) >> 3)
 			| ((buf[0] & 0x20) >> 5)
@@ -192,7 +192,7 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 			mouse_send_buttons(inp, buttons, mpriv->button_state);
 			mpriv->button_state = buttons;
 		}
-		GIIDPRINT_EVENTS("Got IntelliMouse base packet\n");
+		DPRINT_EVENTS("Got IntelliMouse base packet\n");
 	}
 
 	if (len < 4) {
@@ -203,7 +203,7 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 
 	if ((buf[3] & 0x40) == 0x40) {
 		/* 4th byte must be a header byte */
-		GIIDPRINT_EVENTS("Got 3-byte IntelliMouse packet\n");
+		DPRINT_EVENTS("Got 3-byte IntelliMouse packet\n");
 		return 3;
 	}
 
@@ -219,7 +219,7 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got 4-byte IntelliMouse packet\n");
+	DPRINT_EVENTS("Got 4-byte IntelliMouse packet\n");
 	
 	return 4;
 } 
@@ -231,25 +231,25 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_msc(gii_input *inp, uint8 *buf, int len)
+static int parse_msc(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy;
 	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
-	static uint32 B_mousesys[] = {
+	static uint32_t B_mousesys[] = {
 		0x0, 0x2, 0x4, 0x6, 0x1, 0x3, 0x5, 0x7
 	};
 
 	/* check header */
 	if ((buf[0] & 0xf8) != 0x80) {
-		GIIDPRINT_EVENTS("Invalid mousesys packet\n");
+		DPRINT_EVENTS("Invalid mousesys packet\n");
 		return 1;
 	}
 
 	buttons = B_mousesys[(~buf[0] & 0x07)];
 
-	dx =  (sint8) buf[1] + (sint8) buf[3];
-	dy = -(sint8) buf[2] - (sint8) buf[4];
+	dx =  (int8_t) buf[1] + (int8_t) buf[3];
+	dy = -(int8_t) buf[2] - (int8_t) buf[4];
 
 	mouse_send_movement(inp, dx, dy, 0, 0);
 	if (buttons != mpriv->button_state) {
@@ -257,7 +257,7 @@ static int parse_msc(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got mousesys packet\n");
+	DPRINT_EVENTS("Got mousesys packet\n");
 
 	return 5;
 }
@@ -269,25 +269,25 @@ static int parse_msc(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_logi(gii_input *inp, uint8 *buf, int len)
+static int parse_logi(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy;
 	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
-	static uint32 B_logitech[] = {
+	static uint32_t B_logitech[] = {
 		0x0, 0x2, 0x4, 0x6, 0x1, 0x3, 0x5, 0x7
 	};
 
 	/* check header */
 	if (((buf[0] & 0xe0) != 0x80) || ((buf[1] & 0x80) != 0x00)) {
-		GIIDPRINT_EVENTS("Invalid logitech packet\n");
+		DPRINT_EVENTS("Invalid logitech packet\n");
 		return 1;
 	}
 
 	buttons = B_logitech[(buf[0] & 0x07)];
 
-	dx = (buf[0] & 0x10) ?	(sint8)buf[1] : -(sint8)buf[1];
-	dy = (buf[0] & 0x08) ? -(sint8)buf[2] :  (sint8)buf[2];
+	dx = (buf[0] & 0x10) ?	(int8_t)buf[1] : -(int8_t)buf[1];
+	dy = (buf[0] & 0x08) ? -(int8_t)buf[2] :  (int8_t)buf[2];
 
 	mouse_send_movement(inp, dx, dy, 0, 0);
 	if (buttons != mpriv->button_state) {
@@ -295,7 +295,7 @@ static int parse_logi(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got logitech packet\n");
+	DPRINT_EVENTS("Got logitech packet\n");
 
 	return 3;
 }
@@ -307,25 +307,25 @@ static int parse_logi(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_sun(gii_input *inp, uint8 *buf, int len)
+static int parse_sun(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy;
 	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
-	static uint32 B_sun[] = {
+	static uint32_t B_sun[] = {
 		0x0, 0x2, 0x4, 0x6, 0x1, 0x3, 0x5, 0x7
 	};
 
 	/* check header */
 	if ((buf[0] & 0xf8) != 0x80) {
-		GIIDPRINT_EVENTS("Invalid sun packet\n");
+		DPRINT_EVENTS("Invalid sun packet\n");
 		return 1;
 	}
 
 	buttons = B_sun[(~buf[0] & 0x07)];
 
-	dx =  (sint8) buf[1];
-	dy = -(sint8) buf[2];
+	dx =  (int8_t) buf[1];
+	dy = -(int8_t) buf[2];
 
 	mouse_send_movement(inp, dx, dy, 0, 0);
 	if (buttons != mpriv->button_state) {
@@ -333,7 +333,7 @@ static int parse_sun(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got sun packet\n");
+	DPRINT_EVENTS("Got sun packet\n");
 
 	return 3;
 }
@@ -362,18 +362,18 @@ static int parse_sun(gii_input *inp, uint8 *buf, int len)
   stores the RAW buttons in priv->button_state.
 */
 
-static int parse_mman(gii_input *inp, uint8 *buf, int len)
+static int parse_mman(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy;
 	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
-	static uint32 B_mouseman[] = {
+	static uint32_t B_mouseman[] = {
 		0x0, 0x2, 0x1, 0x3, 0x4, 0x6, 0x5, 0x7
 	};
 
 	/* check header */
 	if (((buf[0] & 0x40) != 0x40) || ((buf[1] & 0x40) != 0x00)) {
-		GIIDPRINT_EVENTS("Invalid mouseman packet\n");
+		DPRINT_EVENTS("Invalid mouseman packet\n");
 		return 1;
 	}
 
@@ -382,8 +382,8 @@ static int parse_mman(gii_input *inp, uint8 *buf, int len)
 		buttons = (mpriv->button_state & 0x4) |
 			((buf[0] & 0x30) >> 4);
 		
-		dx = (sint8) (((buf[0] & 0x03) << 6) | (buf[1] & 0x3f));
-		dy = (sint8) (((buf[0] & 0x0c) << 4) | (buf[2] & 0x3f));
+		dx = (int8_t) (((buf[0] & 0x03) << 6) | (buf[1] & 0x3f));
+		dy = (int8_t) (((buf[0] & 0x0c) << 4) | (buf[2] & 0x3f));
 
 		mouse_send_movement(inp, dx, dy, 0, 0);
 		mouse_send_buttons(inp, B_mouseman[buttons],
@@ -392,7 +392,7 @@ static int parse_mman(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 		mpriv->parse_state  = 1;
 
-		GIIDPRINT_EVENTS("Got mouseman base packet\n");
+		DPRINT_EVENTS("Got mouseman base packet\n");
 	}
 
 	/* now look for extension byte */
@@ -415,7 +415,7 @@ static int parse_mman(gii_input *inp, uint8 *buf, int len)
 
 	mpriv->button_state = buttons;
 
-	GIIDPRINT_EVENTS("Got mouseman extension packet\n");
+	DPRINT_EVENTS("Got mouseman extension packet\n");
 
 	return 4;
 }
@@ -427,7 +427,7 @@ static int parse_mman(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_ps2(gii_input *inp, uint8 *buf, int len)
+static int parse_ps2(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy;
 	unsigned int buttons;
@@ -435,7 +435,7 @@ static int parse_ps2(gii_input *inp, uint8 *buf, int len)
 
 	/* Check header byte. */
 	if ((buf[0] & 0xc0) != 0) {
-		GIIDPRINT_EVENTS("Invalid PS/2 packet\n");
+		DPRINT_EVENTS("Invalid PS/2 packet\n");
 		return 1;
 	}
 
@@ -450,7 +450,7 @@ static int parse_ps2(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got PS/2 packet\n");
+	DPRINT_EVENTS("Got PS/2 packet\n");
 
 	return 3;
 }
@@ -462,7 +462,7 @@ static int parse_ps2(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
+static int parse_mmanps2(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx = 0, dy = 0, wheel = 0;
 	unsigned int buttons;
@@ -477,7 +477,7 @@ static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
 			: (buf[2] & 0x0f) - 16;
 	} else {
 		if ((buf[0] & 0xc0) != 0) {
-			GIIDPRINT_EVENTS("Invalid MouseMan+ PS/2 packet\n");
+			DPRINT_EVENTS("Invalid MouseMan+ PS/2 packet\n");
 			return 1;
 		}
 		buttons = (buf[0] & 0x07)
@@ -492,7 +492,7 @@ static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got MouseMan+ PS/2 packet\n");
+	DPRINT_EVENTS("Got MouseMan+ PS/2 packet\n");
 
 	return 3;
 }
@@ -504,21 +504,21 @@ static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
 ******************************************************************************
 */
 
-static int parse_imps2(gii_input *inp, uint8 *buf, int len)
+static int parse_imps2(gii_input *inp, uint8_t *buf, int len)
 {
 	int dx, dy, wheel;
 	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 
 	if ((buf[0] & 0xc0) != 0) {
-		GIIDPRINT_EVENTS("Invalid IMPS/2 packet\n");
+		DPRINT_EVENTS("Invalid IMPS/2 packet\n");
 		return 1;
 	}
 
-	buttons = buf[0] & 0x0f;
+	buttons = buf[0] & 0x07;
 	dx = (buf[0] & 0x10) ? buf[1] - 256 : buf[1];
 	dy = (buf[0] & 0x20) ? -(buf[2] - 256) : -buf[2];
-	wheel = (sint8)buf[3];
+	wheel = (int8_t)buf[3];
 
 	mouse_send_movement(inp, dx, dy, 0, wheel);
 	if (buttons != mpriv->button_state) {
@@ -526,7 +526,7 @@ static int parse_imps2(gii_input *inp, uint8 *buf, int len)
 		mpriv->button_state = buttons;
 	}
 
-	GIIDPRINT_EVENTS("Got IMPS/2 packet\n");
+	DPRINT_EVENTS("Got IMPS/2 packet\n");
 
 	return 4;
 }
@@ -552,17 +552,17 @@ static int parse_imps2(gii_input *inp, uint8 *buf, int len)
 /* Init data
 ******************************************************************************
 */
-static uint8 initdata_ps2[] = 
+static uint8_t initdata_ps2[] = 
 /* Make sure the mouse is enabled and in a sane state */
 { PS2_DEFAULT, PS2_SCALE11, PS2_ENABLE };
 
-static uint8 initdata_imps2[] =
+static uint8_t initdata_imps2[] =
 /* This is a "magic" sequence turning on native mode */
 { PS2_SETSAMPLE, 200, PS2_SETSAMPLE, 100, PS2_SETSAMPLE, 80,
 /* Make sure the mouse is enabled and in a sane state */
   PS2_DEFAULT, PS2_SCALE11, PS2_ENABLE };
 
-static uint8 initdata_mmanps2[] =
+static uint8_t initdata_mmanps2[] =
 /* This is a "magic" sequence turning on native mode */
 { PS2_SCALE11, PS2_SETRES, 0, PS2_SETRES, 3, PS2_SETRES, 2, PS2_SETRES, 1,
   PS2_SCALE11, PS2_SETRES, 3, PS2_SETRES, 1, PS2_SETRES, 2, PS2_SETRES, 3,
@@ -658,7 +658,7 @@ static int do_parse_packet(gii_input *inp)
 	used = mpriv->parser(inp, mpriv->packet_buf, 
 			     mpriv->packet_len);
 
-	GIIDPRINT_EVENTS("packet used %d bytes\n", used);
+	DPRINT_EVENTS("packet used %d bytes\n", used);
 
 	return used;
 }
@@ -669,7 +669,7 @@ gii_event_mask GII_mouse_poll(gii_input *inp, void *arg)
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 	int read_len;
 
-	GIIDPRINT_EVENTS("GII_mouse_poll(%p, %p) called\n", inp, arg);
+	DPRINT_EVENTS("GII_mouse_poll(%p, %p) called\n", inp, arg);
 	
 	if (mpriv->eof) {
 		/* End-of-file, don't do any polling */
@@ -685,7 +685,7 @@ gii_event_mask GII_mouse_poll(gii_input *inp, void *arg)
 	} else {
 		if (! FD_ISSET(mpriv->fd, ((fd_set*)arg))) {
 			/* Nothing to read on our fd */
-			GIIDPRINT_EVENTS("GII_mouse_poll: dummypoll\n");
+			DPRINT_EVENTS("GII_mouse_poll: dummypoll\n");
 			return 0;
 		}
 	}
@@ -703,7 +703,7 @@ gii_event_mask GII_mouse_poll(gii_input *inp, void *arg)
 		if (read_len == 0) {
 			/* End-of-file occured */
 			mpriv->eof = 1;
-			GIIDPRINT_EVENTS("Mouse: EOF occured on fd: %d\n",
+			DPRINT_EVENTS("Mouse: EOF occured on fd: %d\n",
 					 mpriv->fd);
 			return 0;
 		}
@@ -735,7 +735,7 @@ gii_event_mask GII_mouse_poll(gii_input *inp, void *arg)
 		}
 	}
 
-	GIIDPRINT_EVENTS("GII_mouse_poll: done\n");
+	DPRINT_EVENTS("GII_mouse_poll: done\n");
 
 	return mpriv->sent;
 }
