@@ -1,4 +1,4 @@
-/* $Id: key2event.c,v 1.3 2002/02/22 21:51:13 soyt Exp $
+/* $Id: key2event.c,v 1.5 2005/07/29 16:40:59 soyt Exp $
 ******************************************************************************
 
    FreeBSD vgl(3) inputlib key to event converter
@@ -30,7 +30,7 @@
 #include "input-vgl.h"
 #include "keycodes.h"
 
-static uint32 ggi_labels[] = {
+static uint32_t ggi_labels[] = {
 	GIIK_NIL, GIIUC_Escape, GIIUC_1, GIIUC_2, GIIUC_3, GIIUC_4, GIIUC_5,
 	GIIUC_6, GIIUC_7, GIIUC_8, GIIUC_9, GIIUC_0, GIIUC_Minus, GIIUC_Equal,
 	GIIUC_BackSpace, GIIUC_Tab, GIIUC_Q, GIIUC_W, GIIUC_E, GIIUC_R,
@@ -53,11 +53,11 @@ static uint32 ggi_labels[] = {
 
 #define set_lockkey_state(s, l)				\
 	if (!((s) & l ## DOWN)) {			\
-		int i;					\
+		int tmp;				\
 		(s) |= l ## DOWN;			\
 		(s) ^= l ## ED;				\
-		i = (s) & LOCK_MASK;			\
-		ioctl(0, KDSETLED, (caddr_t)&i);	\
+		tmp = (s) & LOCK_MASK;			\
+		ioctl(0, KDSETLED, (caddr_t)&tmp);	\
 	}
 
 static u_int
